@@ -30,14 +30,14 @@ class GlobalShortcutsPlugin : public Plugin {
     // Q_PLUGIN_METADATA(IID "org.kde.ActivityManager.plugins.globalshortcutsplugin")
 
 public:
-    explicit GlobalShortcutsPlugin(QObject *parent = Q_NULLPTR, const QVariantList &args = QVariantList());
-    ~GlobalShortcutsPlugin() Q_DECL_OVERRIDE;
+    explicit GlobalShortcutsPlugin(QObject *parent = nullptr, const QVariantList &args = QVariantList());
+    ~GlobalShortcutsPlugin() override;
 
-    bool init(QHash<QString, QObject *> &modules) Q_DECL_OVERRIDE;
+    bool init(QHash<QString, QObject *> &modules) override;
 
 private Q_SLOTS:
     void activityAdded(const QString &activity);
-    void activityRemoved(const QString &activity = QString());
+    void activityRemoved(const QString &activity);
     void activityChanged(const QString &activity);
 
 private:
